==> haskell-lucid-2.9.11-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-JLNusYKhD7LImCEBVlhsi7
key: lucid-2.9.11-JLNusYKhD7LImCEBVlhsi7
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: f6d2afac0cf78472d4688dba09e40327
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.5/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-JLNusYKhD7LImCEBVlhsi7
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.11-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-3O9HH0CTVnR4l63o98qBbx
key: lucid-2.9.11-3O9HH0CTVnR4l63o98qBbx
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: 4f08662ab1eb8bb2c9a913d71cb3d1cb
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.5/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-3O9HH0CTVnR4l63o98qBbx
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
